@@ -1,7 +1,11 @@
 from .cookie_session import PasetoCookieSessionInterface
+from .exceptions import DecodeError, EncodeError, FlaskPasetoError
+from .issuer import PasetoIssuer
 from .login_manager import PasetoLoginManager
+from .token import Token, current_paseto, paseto_required
+from .verifier import PasetoVerifier
 
-__version__ = "0.2.0"
+__version__ = "0.4.2"
 __title__ = "Flask PASETO Extended"
 __description__ = "PASETO (Platform-Agnostic Security Tokens) for Flask applications."
 __url__ = "https://github.com/dajiaji/flask-paseto-extended"
@@ -14,4 +18,12 @@ __copyright__ = "Copyright 2021 Ajitomi Daisuke"
 __all__ = [
     "PasetoCookieSessionInterface",
     "PasetoLoginManager",
+    "PasetoIssuer",
+    "PasetoVerifier",
+    "Token",
+    "current_paseto",
+    "paseto_required",
+    "FlaskPasetoError",
+    "EncodeError",
+    "DecodeError",
 ]
